@@ -2,7 +2,10 @@ import re
 
 from faker.providers.automotive.de_DE import Provider as DeDeAutomotiveProvider
 from faker.providers.automotive.es_ES import Provider as EsEsAutomotiveProvider
+from faker.providers.automotive.ro_RO import Provider as RoRoAutomotiveProvider
 from faker.providers.automotive.ru_RU import Provider as RuRuAutomotiveProvider
+from faker.providers.automotive.sk_SK import Provider as SkSkAutomotiveProvider
+from faker.providers.automotive.tr_TR import Provider as TrTrAutomotiveProvider
 
 
 class _SimpleAutomotiveTestMixin:
@@ -19,6 +22,14 @@ class _SimpleAutomotiveTestMixin:
             self.perform_extra_checks(license_plate, match)
 
 
+class TestSkSk(_SimpleAutomotiveTestMixin):
+    """Test sk_SK automotive provider methods"""
+    license_plate_pattern = re.compile(r'(?P<prefix>[A-Z]{2})\d{3}[A-Z]{2}')
+
+    def perform_extra_checks(self, license_plate, match):
+        assert match.group('prefix') in SkSkAutomotiveProvider.license_plate_prefix
+
+
 class TestPtBr(_SimpleAutomotiveTestMixin):
     """Test pt_BR automotive provider methods"""
     license_plate_pattern = re.compile(r'[A-Z]{3}-\d{4}')
@@ -155,7 +166,44 @@ class TestEsEs:
             assert self.old_format_pattern.match(plate)
             assert plate[:2] == "CA"
 
-    def test_plate_format(self, faker):
-        plate = faker.license_plate()
-        assert isinstance(plate, str)
-        assert self.new_format_pattern.match(plate) or self.old_format_pattern.match(plate)
+    def test_plate_format(self, faker, num_samples):
+        for _ in range(num_samples):
+            plate = faker.license_plate()
+            assert isinstance(plate, str)
+            assert self.new_format_pattern.match(plate) or self.old_format_pattern.match(plate)
+
+
+class TestThTh(_SimpleAutomotiveTestMixin):
+    """Test th_TH automotive provider methods"""
+    license_plate_pattern = re.compile(
+        r'(\d [ก-ฮ]{2} \d{1,4})|'  # car
+        r'([ก-ฮ]{2} \d{1,4})|'  # car
+        r'([ก-ฮ]{3} \d{1,3})|'  # motorcycle
+        r'(\d{2}-\d{4})',  # truck
+        )
+
+
+class TestTrTr(_SimpleAutomotiveTestMixin):
+    """Test tr_TR automotive provider methods"""
+    license_plate_pattern = re.compile(
+        r'\d{2} [A-Z] \d{4}|'
+        r'\d{2} [A-Z] \d{5}|'
+        r'\d{2} [A-Z]{2} \d{3}|'
+        r'\d{2} [A-Z]{2} \d{4}|'
+        r'\d{2} [A-Z]{3} \d{2}|'
+        r'\d{2} [A-Z]{3} \d{3}',
+    )
+
+    def perform_extra_checks(self, license_plate, match):
+        [city_code, letters, _] = license_plate.split(' ')
+        assert int(city_code) in range(1, 82)
+        assert all(letter in TrTrAutomotiveProvider.ascii_uppercase_turkish for letter in letters)
+
+
+class TestRoRo(_SimpleAutomotiveTestMixin):
+    """Test ro_RO automotive provider methods"""
+    license_plate_pattern = re.compile(
+        r'(?P<prefix>[A-Z]{1,2})-\d{2,3}-[A-Z]{3}')
+
+    def perform_extra_checks(self, license_plate, match):
+        assert match.group('prefix') in RoRoAutomotiveProvider.license_plate_prefix
